import os
import yaml

from fingerprints.types.common import TypesList, TYPES_PATH

CODE_DIR = os.path.dirname(__file__)


def write_python() -> None:
    with open(TYPES_PATH, "r", encoding="utf-8") as fh:
        data: TypesList = yaml.safe_load(fh)
    python_file = os.path.join(CODE_DIR, "data.py")
    with open(python_file, "w", encoding="utf-8") as pyfh:
        pyfh.write("# generated file, do not edit.\n")
        pyfh.write("from fingerprints.types.common import TypesList\n\n")
        pyfh.write("TYPES: TypesList = %s\n" % repr(data))


if __name__ == "__main__":
    write_python()



import os
import yaml
from typing import Set
from normality import slugify

from fingerprints.types.common import TYPES_PATH, TypesList


def check_types_file() -> None:
    with open(TYPES_PATH, "r") as fh:
        data: TypesList = yaml.safe_load(fh)

    mains: Set[str] = set()
    forms: Set[str] = set()
    for type in data["types"]:
        main = type["main"].lower()
        type["main"] = type["main"]
        if main in mains:
            print("DUPLICATE MAIN", repr(main))
        elif main in forms:
            print("MAIN IS FORM ELSEHWERE", main)
        mains.add(main)
        forms.add(main)
        cur_forms: Set[str] = set()
        for form in type["forms"]:
            form = form.lower()
            if form == main:
                continue
            cur_forms.add(form)
            if form in forms:
                print("DUPLICATE FORM", form)
            forms.add(form)

        type["forms"] = sorted(cur_forms)

        # print(type)

    data["types"] = sorted(data["types"], key=lambda t: t["main"])
    with open(TYPES_PATH, "wb") as fh:
        fh.write(
            yaml.dump(
                data,
                allow_unicode=True,
                encoding="utf-8",
                sort_keys=False,
            )
        )


if __name__ == "__main__":
    check_types_file()



from typing import Optional
from normality import collapse_spaces

from fingerprints.cleanup import clean_strict
from fingerprints.types.replacer import get_replacer, NormFunc


def replace_types(text: Optional[str]) -> Optional[str]:
    """Chomp down company types to a more convention form."""
    return get_replacer()(text)


def remove_types(text: Optional[str], clean: NormFunc = clean_strict) -> Optional[str]:
    """Remove company type names from a piece of text.

    WARNING: This converts to ASCII by default, pass in a different
    `clean` function if you need a different behaviour."""
    text = clean(text)
    removed = get_replacer(clean, remove=True)(text)
    return collapse_spaces(removed)



import re
import logging
from typing import Optional
from normality import collapse_spaces, ascii_text, category_replace

from fingerprints.constants import WS

log = logging.getLogger(__name__)

CHARACTERS_REMOVE_RE = re.compile(r"[\.\']")

PREFIXES_RAW_LIST = [
    "Mr",
    "Ms",
    "Mrs",
    "Mister",
    "Miss",
    "Madam",
    "Madame",
    "Monsieur",
    "Mme",
    "Mmme",
    "Herr",
    "Hr",
    "Frau",
    "Fr",
    "The",
    "Fräulein",
    "Senor",
    "Senorita",
    "Sr",
    "Sir",
    "Lady",
    "The",
    "de",
    "of",
]
PREFIXES_RAW = "|".join(PREFIXES_RAW_LIST)
NAME_PATTERN_ = r"^\W*((%s)\.?\s+)*(?P<term>.*?)([\'’]s)?\W*$"
NAME_PATTERN_ = NAME_PATTERN_ % PREFIXES_RAW
PREFIXES = re.compile(NAME_PATTERN_, re.I | re.U)


def clean_entity_name(name: str) -> str:
    match = PREFIXES.match(name)
    if match is not None:
        name = match.group("term")
    return name


def clean_strict(text: Optional[str], boundary: str = WS) -> Optional[str]:
    """Super-hardcore string scrubbing."""
    # transliterate to ascii
    text = ascii_text(text)
    if not isinstance(text, str):
        return None
    # replace punctuation and symbols
    text = CHARACTERS_REMOVE_RE.sub("", text)
    text = text.lower()
    text = category_replace(text)
    text = collapse_spaces(text)
    return text
    # if text is None:
    #     return None
    # pad out for company type replacements
    # return "".join((boundary, text, boundary))



import os
from typing import TypedDict, List

TYPES_PATH = os.path.join(os.path.dirname(__file__), "types.yml")


class TypeEntry(TypedDict):
    main: str
    forms: List[str]


class TypesList(TypedDict):
    types: List[TypeEntry]



from fingerprints.fingerprint import fingerprint
from fingerprints.cleanup import clean_entity_name
from fingerprints.types import remove_types

generate = fingerprint

__all__ = ["fingerprint", "generate", "clean_entity_name", "remove_types"]



# generated file, do not edit.
from fingerprints.types.common import TypesList

TYPES: TypesList = {
    "types": [
        {"main": "3at", "forms": ["закрытае ацыянернае таварыства"]},
        {
            "main": "aat",
            "forms": [
                "adkritaye aktsiyanernaye tavaristva",
                "adkrytae akcyyanernae tavarystva",
                "аат",
                "адкрытае акцыянернае таварыства",
            ],
        },
        {"main": "ab", "forms": ["abp", "aktiebolag", "publikt aktiebolag"]},
        {"main": "abv", "forms": ["aandeelhouder-bestuurde vennootschap"]},
        {
            "main": "ad",
            "forms": [
                "a.d",
                "a.d.",
                "akcionarsko društvo",
                "aktsionerno druzhestvo",
                "а.д",
                "ад",
                "акционарско друштво",
                "акционерно дружество",
            ],
        },
        {
            "main": "adsic",
            "forms": [
                "adsitz",
                "aktsionerno druzhestvo sas spetsialna investitsionna tsel",
                "адсиц",
                "акционерно дружество със специална инвестиционна цел",
            ],
        },
        {"main": "ae", "forms": ["anónimi etería", "ανώνυμη εταιρεία"]},
        {
            "main": "ag",
            "forms": [
                "aksiyadorlik jamiyati",
                "aktiengesellschaft",
                "акциядорлик жамияти",
            ],
        },
        {"main": "amba", "forms": ["andelsselskab med begrænset ansvar"]},
        {"main": "anl", "forms": ["andelslag"]},
        {"main": "ano", "forms": ["автономная некоммерческая организация", "ано"]},
        {"main": "anpo", "forms": ["autonomous non-profit organization"]},
        {
            "main": "ao",
            "forms": [
                "anonim ortaklık",
                "joint stock company",
                "jsc",
                "public stock company",
                "акционерная компания с ограниченной ответственностью",
                "акционерное общество",
                "акціонерного товариства",
            ],
        },
        {"main": "aps", "forms": ["anpartsselskab"]},
        {
            "main": "as",
            "forms": [
                "akciju sabiedrība",
                "akciová společnost",
                "akciová spoločnosť",
                "aktieselskab",
                "aktieselskabet",
                "aktsiaselts",
                "anonim şirket",
            ],
        },
        {
            "main": "asbl",
            "forms": [
                "aisbl",
                "association internationale sans but lucratif",
                "association sans but lucratif",
            ],
        },
        {"main": "asc", "forms": ["açıq səhmdar cəmiyyəti"]},
        {"main": "ay", "forms": ["avoin yhtiö"]},
        {"main": "bhd", "forms": ["berhad"]},
        {"main": "bv", "forms": ["besloten vennootschap"]},
        {
            "main": "bvba",
            "forms": ["besloten vennootschap met beperkte aansprakelijkheid"],
        },
        {"main": "ca", "forms": ["compañía anónima"]},
        {"main": "co", "forms": ["company", "компания"]},
        {
            "main": "co ltd",
            "forms": ["cia ltda", "co., ltd.", "co.ltd", "compañía limitada"],
        },
        {
            "main": "coop",
            "forms": [
                "co-op",
                "cooperation",
                "cooperative",
                "coopératif",
                "coopération",
                "coopérative",
                "kooperatsia",
                "sociedad cooperativa",
                "spółdzielni",
                "кооперация",
            ],
        },
        {"main": "corp", "forms": ["corporation"]},
        {"main": "cp", "forms": ["fond commun de placement"]},
        {"main": "cs", "forms": ["ህብረት ስራ ማህበራት"]},
        {"main": "cty cp", "forms": ["công ty cổ phần"]},
        {"main": "cty tnhh", "forms": ["công ty trách nhiệm hữu hạn"]},
        {
            "main": "cty tnhh mtv",
            "forms": ["công ty trách nhiệm hữu hạn một thành viên"],
        },
        {
            "main": "cv",
            "forms": [
                "comm. v",
                "commanditaire vennootschap",
                "gewone commanditaire vennootschap",
            ],
        },
        {
            "main": "cva",
            "forms": ["comm. va", "commanditaire vennootschap op aandelen"],
        },
        {
            "main": "cvba",
            "forms": ["coöperatieve vennootschap met beperkte aansprakelijkheid"],
        },
        {
            "main": "cvoa",
            "forms": ["coöperatieve vennootschap met onbeperkte aansprakelijkheid"],
        },
        {"main": "cía", "forms": ["compañía"]},
        {"main": "dd", "forms": ["d.d.", "dioničko društvo"]},
        {"main": "dis tic ltd", "forms": ["dis.tic.ltd"]},
        {"main": "dnnn", "forms": ["doanh nghiệp nhà nước"]},
        {
            "main": "dno",
            "forms": ["d.n.o.", "društvo s neograničenom solidarnom odgovornošću"],
        },
        {"main": "dntn", "forms": ["doanh nghiệp tư nhân"]},
        {
            "main": "doo",
            "forms": [
                "d.o.o.",
                "društvo s ograničenom odgovornošću",
                "društvo sa ograničenom odgovornošću",
                "д.о.о.",
                "доо",
                "друштво са ограниченом одговорношћу",
            ],
        },
        {"main": "dp", "forms": ["društveno preduzeće", "дп", "друштвено предузеће"]},
        {"main": "dtnn", "forms": ["doanh nghiệp có vốn đầu tư nước ngoài"]},
        {
            "main": "dzzd",
            "forms": [
                "druzhestvo uchredeno po zakona za zadalzheniyata i dogovorite",
                "дззд",
                "дружество учредено по закона за задълженията и договорите",
            ],
        },
        {
            "main": "ead",
            "forms": [
                "ednolichno aktsionerno druzhestvo",
                "еад",
                "еднолично акционерно дружество",
            ],
        },
        {
            "main": "ebvba",
            "forms": [
                "eenpersoons besloten vennootschap met beperkte aansprakelijkheid"
            ],
        },
        {
            "main": "ed",
            "forms": ["evropeysko druzhestvo", "eвропейско дружество", "ед"],
        },
        {
            "main": "eeig",
            "forms": [
                "european economic interest grouping",
                "evropeysko obedinenie po ikonomicheski interesi",
                "европейско обединение по икономически интереси",
                "еоии",
            ],
        },
        {"main": "eg", "forms": ["eingetragene genossenschaft", "genossenschaft"]},
        {"main": "ehf", "forms": ["einkahlutafélag"]},
        {"main": "ei", "forms": ["entreprise individuelle"]},
        {
            "main": "eireli",
            "forms": ["empresa individual de responsabilidade limitada"],
        },
        {"main": "eirl", "forms": ["empresa individual de responsabilidad limitada"]},
        {"main": "ek. för.", "forms": ["ekonomisk förening"]},
        {
            "main": "ekd",
            "forms": [
                "evropeysko kooperativno druzhestvo",
                "eвропейско кооперативно дружество",
                "екд",
            ],
        },
        {"main": "ent.", "forms": ["enterprise"]},
        {
            "main": "eood",
            "forms": [
                "ednolichno druzhestvo s ogranichena otgovornost",
                "еднолично дружество с ограничена отговорност",
                "еоод",
            ],
        },
        {"main": "ep", "forms": ["empresa pública"]},
        {"main": "esv", "forms": ["economisch samenwerkingsverband"]},
        {"main": "et", "forms": ["ednolichen targovets", "едноличен търговец", "ет"]},
        {
            "main": "eu",
            "forms": ["eingetragenes einzelunternehmen", "empresa unipersonal"],
        },
        {
            "main": "eurl",
            "forms": ["entreprise unipersonnelle à responsabilité limitée"],
        },
        {"main": "ev", "forms": ["eingetragener verein"]},
        {"main": "exp", "forms": ["export"]},
        {"main": "exp corp", "forms": ["exp.corp"]},
        {"main": "f:ma", "forms": ["enskild näringsidkare"]},
        {"main": "fa", "forms": ["firma"]},
        {"main": "fie", "forms": ["füüsilisest isikust ettevõtja"]},
        {"main": "fmba", "forms": ["forening med begrænset ansvar"]},
        {"main": "fze", "forms": ["free zone establishment"]},
        {"main": "gbr", "forms": ["gesbr", "gesellschaft des bürgerlichen rechts"]},
        {"main": "gie", "forms": ["groupement d'intérêt économique"]},
        {"main": "giu", "forms": ["gospodarsko interesno udruženje"]},
        {"main": "gk", "forms": ["合同会社"]},
        {
            "main": "gmbh",
            "forms": [
                "g.m.b.h",
                "gesellschaft mit besch haftung",
                "gesellschaft mit besch. haftung",
                "gesellschaft mit beschr haftung",
                "gesellschaft mit beschr. haftung",
                "gesellschaft mit beschränkter haftung",
                "gmbh & co.",
                "gmbh & co. kg",
                "gmbh and сo. kg",
                "gmbh und co. kg",
                "mit besch haftung",
                "mit beschr haftung",
                "mit beschränkter haftung",
                "гмбх енд ко. кг",
            ],
        },
        {"main": "gmk", "forms": ["合名会社"]},
        {"main": "gp", "forms": ["general partnership"]},
        {"main": "gs", "forms": ["gensidigt selskab"]},
        {"main": "gsk", "forms": ["合資会社"]},
        {"main": "haao", "forms": ["halka açık anonim ortaklık"]},
        {"main": "hf", "forms": ["hlutafélag"]},
        {"main": "htx", "forms": ["hợp tác xã"]},
        {"main": "huf", "forms": ["hindu undivided family"]},
        {
            "main": "ii",
            "forms": [
                "inteprinderea individuala",
                "interprinderea individuală",
                "intreprindere individuala",
                "intreprindere individuală",
                "intreprinderea ibdividuala",
                "intreprinderea individuala",
                "intreprinderea individuală",
                "intreprinderea indiviuala",
                "intreprinzator individual",
                "înterprinderea individuală",
                "întreprindera individuală",
                "întreprindere individuală",
                "întreprinderea individualî",
                "întreprinderea individuală",
                "întreprindserea individuală",
                "întreprinzător individual",
                "întreprinzătorul individual",
            ],
        },
        {"main": "ik", "forms": ["individuālais komersants"]},
        {"main": "im", "forms": ["întreprinderea municipală"]},
        {"main": "imp", "forms": ["import"]},
        {"main": "imp and", "forms": ["imp.and"]},
        {"main": "inc", "forms": ["incorp", "incorporated", "incorporée"]},
        {"main": "ins", "forms": ["insaat"]},
        {"main": "ins oto san tic", "forms": ["ins.oto.san.tic"]},
        {"main": "intl", "forms": ["international", "internationale", "інтернейшнл"]},
        {
            "main": "is",
            "forms": [
                "interessentskab",
                "intreprindere de stat alimentatiei publice",
                "intreprinderea de stat",
                "întreprinderea de stat",
            ],
        },
        {"main": "ivs", "forms": ["iværksætterselskab"]},
        {
            "main": "jdoo",
            "forms": ["j.d.o.o", "jednostavno društvo s ograničenom odgovornošću"],
        },
        {"main": "jp", "forms": ["javno preduzeće", "јавно предузеће", "јп"]},
        {"main": "jscb", "forms": ["joint stock commercial bank"]},
        {"main": "jtd", "forms": ["j.t.d.", "javno trgovačko društvo"]},
        {"main": "ju", "forms": ["(ju)", "jusikhoesa", "㈜", "주식회사"]},
        {"main": "jv", "forms": ["joint venture"]},
        {"main": "kb", "forms": ["kommanditbolag"]},
        {
            "main": "kd",
            "forms": [
                "k.d.",
                "komanditno druzhestvo",
                "komanditno društvo",
                "к.д",
                "кд",
                "командитно дружество",
                "командитно друштво",
            ],
        },
        {
            "main": "kda",
            "forms": [
                "komanditno druzhestvo s aktsii",
                "кда",
                "командитно дружество с акции",
            ],
        },
        {"main": "keg", "forms": ["kommanditerwerbsgesellschaft"]},
        {
            "main": "kft",
            "forms": [
                "korlatolt felelossegu tarsasag",
                "korlátolt felelősségü társaság, organizační složka",
                "korlátolt felelősségű társaság",
            ],
        },
        {"main": "kg", "forms": ["kommanditgesellschaft"]},
        {"main": "kk", "forms": ["株式会社"]},
        {"main": "koll. şti.", "forms": ["kolektif şirket"]},
        {"main": "kom. şti", "forms": ["komandit şirket"]},
        {"main": "koop", "forms": ["kooperatif şirket"]},
        {
            "main": "ks",
            "forms": [
                "komanditní společnost",
                "komandītsabiedrība",
                "kommanditselskab",
            ],
        },
        {"main": "ky", "forms": ["kommandiittiyhtiö"]},
        {
            "main": "llc",
            "forms": [
                "limited liability company",
                "tavaristva z abmezhavanaj adkaznastsiu",
                "tob",
                "акціонерне товариство",
                "тзов",
                "тов",
                "товариство з обмеженою відповідальністю",
            ],
        },
        {"main": "llp", "forms": ["limited liability partnership", "有限責任事業組合"]},
        {"main": "lo", "forms": ["limited ortaklık"]},
        {"main": "loj", "forms": ["lojistik"]},
        {"main": "lp", "forms": ["limited partnership", "兩合公司"]},
        {
            "main": "ltd",
            "forms": [
                "lda.",
                "limitada",
                "limited",
                "limited by guarantee",
                "limited by shares",
                "limited company",
                "limitée",
                "ltd.",
                "ltd. co.",
                "ltda",
                "private company with limited liability",
                "private limited company",
                "private limited liability company",
                "pte ltd.",
                "sociedada limitada",
                "sociedade limitada",
                "компания с ограниченной ответственностью",
                "лимитед",
                'בע"מ',
                "有限公司",
            ],
        },
        {"main": "ltd sti", "forms": ["limited şirket", "ltd.sti"]},
        {
            "main": "mchj",
            "forms": ["mas'uliyati cheklangan jamiyat", "масъулияти чекланган жамият"],
        },
        {"main": "mmc", "forms": ["məhdud məsuliyyətli cəmiyyət"]},
        {"main": "mtü", "forms": ["mittetulundusühing"]},
        {"main": "na", "forms": ["national association"]},
        {"main": "nk", "forms": ["nin'i kumiai", "任意組合"]},
        {"main": "nl", "forms": ["no liability"]},
        {
            "main": "np",
            "forms": ["некоммерческое партнерство", "некоммерческое партнёрство", "нп"],
        },
        {"main": "nv", "forms": ["naamloze vennootschap"]},
        {
            "main": "oaj",
            "forms": ["ochiq aksiyadorlik jamiyati", "очиқ акциядорлик жамияти"],
        },
        {
            "main": "oao",
            "forms": [
                "ojsc",
                "open joint stock company",
                "otkrytoe akcionernoe obshchestvo",
                "otkrytoe aktsionernoe obshchestvo",
                "оао",
                "открытое акционерное общество",
            ],
        },
        {
            "main": "od",
            "forms": ["o.d.", "ortačko društvo", "о.д.", "од", "ортачко друштво"],
        },
        {
            "main": "odo",
            "forms": [
                "obshchestvo s dopolnitel'noj otvetstvennost'yu",
                "общество с дополнительной ответственностью",
                "одо",
            ],
        },
        {"main": "oeg", "forms": ["offene erwerbsgesellschaft"]},
        {"main": "og", "forms": ["offene gesellschaft"]},
        {"main": "ok", "forms": ["oilaviy korxona", "оилавий корхона"]},
        {"main": "ong", "forms": ["organização não governamental"]},
        {
            "main": "ood",
            "forms": [
                "drujestvo s ogranichena otgovornost",
                "druzhestvo s ogranichena otgovornost",
                "дружество с ограничена отговорност",
                "оод",
            ],
        },
        {
            "main": "ooo",
            "forms": [
                "obshchestvo s ogranichennoj otvetstvennost'yu",
                "oсoo",
                "ликвидационная комиссия общества с ограниченной ответственностью",
                "ликвидационная комиссия общество с ограниченной ответственностью",
                "ликвидационная комиссия ооо",
                "общество с ограниченной ответственностью",
                "общество с ограниченной ответственностью строительная компания",
                "общество с ограниченной ответственностью торговый дом",
                "общество с ограниченной ответственностью управляющая компания",
                "общество с ограниченной ответственностью фирма",
                "общество с ограниченной ответственностью частная охранная организация",
                "общество с ограниченной ответственностью частное охранное предприятие",
                "ооо",
            ],
        },
        {"main": "opg", "forms": ["obiteljsko poljoprivredno gospodarstvo"]},
        {"main": "ops", "forms": ["obecně prospěšná společnost"]},
        {"main": "os", "forms": ["občanské sdružení."]},
        {
            "main": "oscip",
            "forms": ["organização da sociedade civil de interesse público"],
        },
        {"main": "osk", "forms": ["osuuskunta"]},
        {"main": "owm", "forms": ["onderlinge waarborgmaatschappij"]},
        {"main": "oy", "forms": ["osakeyhtiö"]},
        {"main": "oyj", "forms": ["julkinen osakeyhtiö"]},
        {"main": "oü", "forms": ["osaühing"]},
        {"main": "pc", "forms": ["ኮርፖሬሽን"]},
        {"main": "pe", "forms": ["የመንግስት ልማት ድርጅቶች"]},
        {
            "main": "peec",
            "forms": ["public establishment with economic characteristics"],
        },
        {
            "main": "plc",
            "forms": ["public limited company", "ሃላፊነቱ የተወሰነ የግል ማህበር", "股份有限公司"],
        },
        {"main": "plt", "forms": []},
        {"main": "pp", "forms": ["приватне підприємство"]},
        {"main": "pr", "forms": ["preduzetnik", "пр", "предузетник"]},
        {"main": "ps", "forms": ["partnerselskab", "pilnsabiedrība"]},
        {"main": "pse", "forms": ["public sector enterprise"]},
        {"main": "psu", "forms": ["public sector undertaking"]},
        {"main": "pt", "forms": ["perseroan terbatas"]},
        {"main": "pt tbk", "forms": ["perseroan terbatas terbuka"]},
        {
            "main": "pty",
            "forms": ["proprietary limited", "proprietary limited company", "pty ltd"],
        },
        {"main": "qk", "forms": ["qo'shma korxona", "қўшма корхона"]},
        {
            "main": "qmj",
            "forms": ["qo'shimcha ma'suliyatli jamiyat", "қўшимча масъулиятли жамият"],
        },
        {
            "main": "qsc",
            "forms": ["qapalı səhmdar cəmiyyəti", "qapalı tipli səhmdar cəmiyyəti"],
        },
        {
            "main": "rao",
            "forms": [
                "pao",
                "pjsc",
                "private joint stock company",
                "пао",
                "приватне акціонерне товариство",
                "публичное акционерное общество",
            ],
        },
        {"main": "rp", "forms": ["rekisteröity puolue"]},
        {"main": "rs", "forms": ["säätiö"]},
        {"main": "ry", "forms": ["rekisteröity yhdistys"]},
        {"main": "s. en c.", "forms": ["comandita simple"]},
        {"main": "s.cra.", "forms": ["sociedad comanditaria"]},
        {
            "main": "sa",
            "forms": [
                "s.a.",
                "sarf",
                "sociedad anonima",
                "sociedad anónima",
                "sociedad en comandita por acciones",
                "sociedad por acciones",
                "sociedada anonima",
                "sociedade anónima",
                "sociedade anônima",
                "sociedá anónima",
                "societat anònima",
                "societate pe acțiuni",
                "societatea pe actiuni",
                "societatea pe acţiuni",
                "societateare pe actiuni",
                "società anonima",
                "société anonyme",
                "société par actions de régime fédéral",
                "société par actions par loi sur les sociétés par actions",
                "spółka akcyjna",
                "شركة خفية الإسم",
            ],
        },
        {"main": "sad", "forms": ["sociedad anónima deportiva"]},
        {"main": "sae", "forms": ["sharikat al-mossahamah"]},
        {"main": "san", "forms": ["sanayi"]},
        {"main": "san as", "forms": ["san.a.s"]},
        {"main": "san tic", "forms": ["san.tic"]},
        {"main": "san tic ltd", "forms": ["san.tic.ltd."]},
        {"main": "san tic ltd sti", "forms": ["san.tic.ltd.sti"]},
        {"main": "san ve", "forms": ["san.ve"]},
        {"main": "saoc", "forms": ["société anonyme omanaise close"]},
        {"main": "saog", "forms": ["société anonyme omanaise générale"]},
        {"main": "sapa", "forms": ["società in accomandita per azioni"]},
        {
            "main": "sarl",
            "forms": [
                "société à responsabilité limitée",
                "شّركة ذات مسؤوليّات محدودة ش.م.م",
            ],
        },
        {
            "main": "sas",
            "forms": [
                "sociedades por acciones simplificada",
                "société par actions simplifiée",
            ],
        },
        {
            "main": "sc",
            "forms": [
                "compania comerciala si de productie societatea cu responsabilitate limitata",
                "sociedad colectiva",
                "societatea comercială",
                "አክሲዩን ማህበር",
            ],
        },
        {
            "main": "sca",
            "forms": ["comandita por acciones", "société en commandite par actions"],
        },
        {"main": "scc", "forms": ["société commerciale canadienne"]},
        {"main": "sce", "forms": ["societas cooperativa europaea"]},
        {"main": "scei", "forms": ["sociedad de capital e industria"]},
        {"main": "scop", "forms": ["société coopérative de production"]},
        {"main": "scpa", "forms": ["sociedad civil privada"]},
        {
            "main": "scs",
            "forms": [
                "secs",
                "sociedad en comandita simple",
                "société en commandite simple",
            ],
        },
        {
            "main": "sd",
            "forms": [
                "s-ie",
                "sabiratelno druzhestvo (sd)/sadruzhie",
                "sd/s-ie",
                "с-ие",
                "сд",
                "събирателно дружество",
                "събирателно дружество (сд)/съдружие",
            ],
        },
        {"main": "sdn bhd", "forms": ["sendirian berhad"]},
        {"main": "se", "forms": ["sociedad del estado", "societas europaea"]},
        {"main": "sem", "forms": ["société d'économie mixte"]},
        {"main": "sep", "forms": ["société en participation"]},
        {"main": "sf", "forms": ["sameignarfélag"]},
        {
            "main": "sgr",
            "forms": [
                "sociedad de garantia reciproca",
                "sociedad de garantía reciproca",
            ],
        },
        {"main": "sh.a", "forms": ["shoqëri aksionere"]},
        {"main": "shpk", "forms": ["sh.p.k", "shoqëri me përgjegjësi të kufizuar"]},
        {"main": "sia", "forms": ["sabiedrība ar ierobežotu atbildību"]},
        {"main": "sicaf", "forms": ["société d'investissement à capital fixe"]},
        {"main": "sicav", "forms": ["société d'investissement à capital variable"]},
        {"main": "sjsc", "forms": ["дат", "державне акціонерне товариство"]},
        {"main": "sll", "forms": ["sociedad limitada laboral"]},
        {"main": "slne", "forms": ["s.l.n.e.", "sociedad limitada nueva empresa"]},
        {"main": "sm pte ltd.", "forms": ["single member private limited company"]},
        {"main": "smba", "forms": ["selskab med begrænset ansvar"]},
        {"main": "snc", "forms": ["société en nom collectif"]},
        {"main": "snt", "forms": ["садоводческое некоммерческое товарищество"]},
        {
            "main": "sp",
            "forms": [
                "s.p.",
                "samostalni preduzetnik",
                "sole proprietorship",
                "státní podnik",
            ],
        },
        {"main": "spa", "forms": ["società per azioni"]},
        {"main": "spe", "forms": ["societas privata europaea"]},
        {"main": "spf", "forms": ["stichting particulier fonds"]},
        {
            "main": "sprl",
            "forms": [
                "société privée à responsabilité limitée",
                "société privée à responsabilité limitée unipersonnelle",
            ],
        },
        {
            "main": "spzoo",
            "forms": [
                "sp. z o.o.",
                "sp. z o.o. sp.k",
                "spółka z ograniczoną odpowiedzialnością",
            ],
        },
        {
            "main": "srl",
            "forms": [
                "intreprinderea cu responsabilitate limitata",
                "s.r.l",
                "s.r.l.",
                "sicietatea de raspundere limitata",
                "sociedad de responsabilidad limitada",
                "societata cu raspundere limitata",
                "societate cu rasponbilitate limitata",
                "societate cu raspundere limitata",
                "societate cu responsabilitate limiiata",
                "societate cu responsabilitate limitata",
                "societate cu răspundere limitată",
                "societate cu răspundre limitată",
                "societatea cu rasdpundere limitata",
                "societatea cu rasponsabilitate limitata",
                "societatea cu raspundere",
                "societatea cu raspundere limitata",
                "societatea cu raspundere limitate",
                "societatea cu responsabilitate limitata",
                "societatea cu responsabilitatea limitata",
                "societatea cu respundere limitata",
                "societatea cu răspundere",
                "societatea cu răspundere limitată",
                "societatii cu raspunderea limitata",
                "societete cu răspundere limitată",
                "società a responsabilità limitata",
                "socitate cu responsabilitate limitata",
            ],
        },
        {"main": "sro", "forms": ["s.r.o", "společnost s ručením omezeným"]},
        {"main": "stg", "forms": ["stille gesellschaft"]},
        {"main": "sti", "forms": ["sirketi"]},
        {"main": "suarl", "forms": ["شّركة فردية ذات مسؤوليّات محدودة"]},
        {"main": "t:mi", "forms": ["oiminimi"]},
        {"main": "tes", "forms": ["tesisat"]},
        {"main": "tes tek dis", "forms": ["tes.tek.dis"]},
        {"main": "tic", "forms": ["ticaret"]},
        {"main": "tic as", "forms": ["tic.a.s."]},
        {"main": "tic ltd sti", "forms": ["tic.ltd.sti"]},
        {"main": "tk", "forms": ["tokumei kumiai", "匿名組合"]},
        {"main": "too", "forms": ["товарищество с ограниченной ответственностью"]},
        {"main": "tü", "forms": ["täisühing"]},
        {"main": "uab", "forms": ["uždaroji akcinė bendrovė"]},
        {"main": "ud", "forms": ["usaha dagang"]},
        {"main": "uk", "forms": ["unitar korxona", "унитар корхона"]},
        {
            "main": "ultd",
            "forms": [
                "unlimited",
                "unlimited company",
                "unlimited proprietary",
                "unltd",
                "無限公司",
            ],
        },
        {
            "main": "up",
            "forms": [
                "consorzio statale",
                "den føderale statsejede budgetinstitution",
                "empresa orçamental do estado federal",
                "empresa unitaria estatal de la",
                "empresa unitária estatal",
                "entità statali",
                "entreprise unitaire d’état",
                "federal state budgetary enterprise",
                "federal state budgetary institution",
                "federal state institution",
                "federal state unitary enterprise",
                "federalna budżetowa instytucja",
                "federalnoe gosudarstvennoe byudzhetnoe uchrezhdenie",
                "föderales staatseigenes unternehmen",
                "gosudarstvennoe unitarnoe predpriyatie",
                "impresa unitaria statale",
                "staatliches einheitsunternehmen",
                "staatskonzern",
                "state concern",
                "state enterprise",
                "state unitary enterprise",
                "state unitary enterprise of the",
                "státní jednotný podnik",
                "státní koncern",
                "unitarnoe predpriyatie",
                "unіtarnae pradpryemstva",
                "štátny unitárny podnik",
                "государственного унитарного предприятия",
                "государственное унитарное предприятие",
                "гп",
                "гуп",
                "державного унітарного підприємства",
                "унитарное предприятие",
                "унітарнае прадпрыемства",
                "уп",
            ],
        },
        {"main": "uü", "forms": ["usaldusühing"]},
        {"main": "vof", "forms": ["vennootschap onder firma"]},
        {"main": "vos", "forms": ["veřejná obchodní společnost"]},
        {
            "main": "vzw",
            "forms": [
                "internationale vereniging zonder winstoogmerk",
                "ivzw",
                "vereinigung ohne gewinnerzielungsabsicht",
                "vereniging zonder winstoogmerk",
                "vog",
            ],
        },
        {"main": "xk", "forms": ["xususiy korxona", "хусусий корхона"]},
        {"main": "xt", "forms": ["xususiy tadbirkorlik", "хусусий тадбиркорлик"]},
        {"main": "yk", "forms": ["有限会社"]},
        {
            "main": "yoaj",
            "forms": ["yopiq aksiyadorlik jamiyati", "ёпиқ акциядорлик жамияти"],
        },
        {"main": "yu", "forms": ["(yu)", "(유)", "yuhanhoesa", "유한회사"]},
        {
            "main": "zao",
            "forms": [
                "cjsc",
                "closed joint stock company",
                "zakrytoe akcionernoe obshchestvo",
                "zaо",
                "закрите акціонерне товариство",
                "закрытое акционерное общество",
                "зао",
            ],
        },
        {
            "main": "zat",
            "forms": [
                "zakritaye aktsiyanernaye tavaristva",
                "zakrytae akcyyanernae tavarystva",
                "закрытае акцыянернае таварыства",
                "зат",
            ],
        },
        {"main": "zs", "forms": ["z.s.", "zapsaný spolek"]},
        {"main": "şb", "forms": ["şube"]},
        {"main": "пуп", "forms": ["прыватнае унітарнае прадпрыемства"]},
        {
            "main": "тda",
            "forms": [
                "tavarystva z dadatkovaj adkaznascyu",
                "таварыства з дадатковай адказнасцю",
                "тда",
            ],
        },
        {
            "main": "таа",
            "forms": [
                "tavarystva z abmezhavanaj adkaznascyu",
                "таварыства з абмежаванай адказнасцю",
            ],
        },
        {"main": "тбб", "forms": ["төрийн бус байгууллага"]},
        {
            "main": "тсж",
            "forms": [
                "товарищество собственников жилья",
                "товарищество собственников недвижимости",
            ],
        },
        {"main": "хк", "forms": ["хувьцаат компани"]},
        {"main": "ххк", "forms": ["хязгаарлагдмал хариуцлагатай компани"]},
    ]
}



import logging
from typing import Optional
from normality import collapse_spaces, stringify

from fingerprints.constants import BRACKETED, WS
from fingerprints.types import replace_types
from fingerprints.cleanup import clean_entity_name, clean_strict

log = logging.getLogger(__name__)


def fingerprint(
    text: Optional[str], keep_order: bool = False, keep_brackets: bool = False
) -> Optional[str]:
    text = stringify(text)
    if text is None:
        return None

    # this needs to happen before the replacements
    text = text.lower()
    text = clean_entity_name(text)

    if not keep_brackets:
        # Remove any text in brackets
        # This is meant to handle names of companies which include
        # the jurisdiction, like: Turtle Management (Seychelles) Ltd.
        text = BRACKETED.sub(WS, text)

    # Super hard-core string scrubbing
    text = clean_strict(text)
    text = replace_types(text)

    if keep_order:
        text = collapse_spaces(text)
    elif text is not None:
        # final manicure, based on openrefine algo
        parts = [p for p in text.split(WS) if len(p)]
        text = WS.join(sorted(set(parts)))

    if text is None or not len(text):
        return None

    return text



from setuptools import setup, find_packages

with open("README.md") as f:
    long_description = f.read()

setup(
    name="fingerprints",
    version="1.1.1",
    description="A library to generate entity fingerprints.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    classifiers=[
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
    ],
    keywords="names people companies normalisation iso20275",
    author="Friedrich Lindenberg",
    author_email="friedrich@pudo.org",
    url="http://github.com/alephdata/fingerprints",
    license="MIT",
    packages=find_packages(exclude=["tests", "tools"]),
    namespace_packages=[],
    package_data={},
    include_package_data=True,
    zip_safe=False,
    test_suite="nose.collector",
    install_requires=[
        "normality>=2.0.0,<=3.0.0",
    ],
    extras_require={
        "dev": [
            "pytest",
            "pytest-cov",
            "mypy",
            "black",
            "pyyaml",
            "types-pyyaml",
            "bump2version",
        ],
    },
)
